==> openshift-model-miscellaneous-5.12.0-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/BareMetalHostStatusBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class BareMetalHostStatusBuilder extends io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostStatusFluentImpl<io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostStatus,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostStatusBuilder>{
  public BareMetalHostStatusBuilder() {
    this(false);
  }
  public BareMetalHostStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new BareMetalHostStatus(), validationEnabled);
  }
  public BareMetalHostStatusBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public BareMetalHostStatusBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new BareMetalHostStatus(), validationEnabled);
  }
  public BareMetalHostStatusBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostStatusFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostStatus instance) {
    this(fluent, instance, false);
  }
  public BareMetalHostStatusBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostStatusFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withErrorCount(instance.getErrorCount()); 
    fluent.withErrorMessage(instance.getErrorMessage()); 
    fluent.withErrorType(instance.getErrorType()); 
    fluent.withGoodCredentials(instance.getGoodCredentials()); 
    fluent.withHardware(instance.getHardware()); 
    fluent.withHardwareProfile(instance.getHardwareProfile()); 
    fluent.withLastUpdated(instance.getLastUpdated()); 
    fluent.withOperationHistory(instance.getOperationHistory()); 
    fluent.withOperationalStatus(instance.getOperationalStatus()); 
    fluent.withPoweredOn(instance.getPoweredOn()); 
    fluent.withProvisioning(instance.getProvisioning()); 
    fluent.withTriedCredentials(instance.getTriedCredentials()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public BareMetalHostStatusBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostStatus instance) {
    this(instance,false);
  }
  public BareMetalHostStatusBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withErrorCount(instance.getErrorCount()); 
    this.withErrorMessage(instance.getErrorMessage()); 
    this.withErrorType(instance.getErrorType()); 
    this.withGoodCredentials(instance.getGoodCredentials()); 
    this.withHardware(instance.getHardware()); 
    this.withHardwareProfile(instance.getHardwareProfile()); 
    this.withLastUpdated(instance.getLastUpdated()); 
    this.withOperationHistory(instance.getOperationHistory()); 
    this.withOperationalStatus(instance.getOperationalStatus()); 
    this.withPoweredOn(instance.getPoweredOn()); 
    this.withProvisioning(instance.getProvisioning()); 
    this.withTriedCredentials(instance.getTriedCredentials()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostStatus build() {
    BareMetalHostStatus buildable = new BareMetalHostStatus(fluent.getErrorCount(),fluent.getErrorMessage(),fluent.getErrorType(),fluent.getGoodCredentials(),fluent.getHardware(),fluent.getHardwareProfile(),fluent.getLastUpdated(),fluent.getOperationHistory(),fluent.getOperationalStatus(),fluent.getPoweredOn(),fluent.getProvisioning(),fluent.getTriedCredentials());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BareMetalHostStatusBuilder that = (BareMetalHostStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-miscellaneous-6.5.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/BareMetalHostStatusBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class BareMetalHostStatusBuilder extends BareMetalHostStatusFluentImpl<BareMetalHostStatusBuilder> implements VisitableBuilder<BareMetalHostStatus,BareMetalHostStatusBuilder>{
  public BareMetalHostStatusBuilder() {
    this(false);
  }
  public BareMetalHostStatusBuilder(Boolean validationEnabled) {
    this(new BareMetalHostStatus(), validationEnabled);
  }
  public BareMetalHostStatusBuilder(BareMetalHostStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public BareMetalHostStatusBuilder(BareMetalHostStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new BareMetalHostStatus(), validationEnabled);
  }
  public BareMetalHostStatusBuilder(BareMetalHostStatusFluent<?> fluent,BareMetalHostStatus instance) {
    this(fluent, instance, false);
  }
  public BareMetalHostStatusBuilder(BareMetalHostStatusFluent<?> fluent,BareMetalHostStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withErrorCount(instance.getErrorCount()); 
    fluent.withErrorMessage(instance.getErrorMessage()); 
    fluent.withErrorType(instance.getErrorType()); 
    fluent.withGoodCredentials(instance.getGoodCredentials()); 
    fluent.withHardware(instance.getHardware()); 
    fluent.withHardwareProfile(instance.getHardwareProfile()); 
    fluent.withLastUpdated(instance.getLastUpdated()); 
    fluent.withOperationHistory(instance.getOperationHistory()); 
    fluent.withOperationalStatus(instance.getOperationalStatus()); 
    fluent.withPoweredOn(instance.getPoweredOn()); 
    fluent.withProvisioning(instance.getProvisioning()); 
    fluent.withTriedCredentials(instance.getTriedCredentials()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public BareMetalHostStatusBuilder(BareMetalHostStatus instance) {
    this(instance,false);
  }
  public BareMetalHostStatusBuilder(BareMetalHostStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withErrorCount(instance.getErrorCount()); 
    this.withErrorMessage(instance.getErrorMessage()); 
    this.withErrorType(instance.getErrorType()); 
    this.withGoodCredentials(instance.getGoodCredentials()); 
    this.withHardware(instance.getHardware()); 
    this.withHardwareProfile(instance.getHardwareProfile()); 
    this.withLastUpdated(instance.getLastUpdated()); 
    this.withOperationHistory(instance.getOperationHistory()); 
    this.withOperationalStatus(instance.getOperationalStatus()); 
    this.withPoweredOn(instance.getPoweredOn()); 
    this.withProvisioning(instance.getProvisioning()); 
    this.withTriedCredentials(instance.getTriedCredentials()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  BareMetalHostStatusFluent<?> fluent;
  Boolean validationEnabled;
  public BareMetalHostStatus build() {
    BareMetalHostStatus buildable = new BareMetalHostStatus(fluent.getErrorCount(),fluent.getErrorMessage(),fluent.getErrorType(),fluent.getGoodCredentials(),fluent.getHardware(),fluent.getHardwareProfile(),fluent.getLastUpdated(),fluent.getOperationHistory(),fluent.getOperationalStatus(),fluent.getPoweredOn(),fluent.getProvisioning(),fluent.getTriedCredentials());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
